@@ -5,4 +5,6 @@ from .parser import Parser
 
 class ExceptionParser(Parser):
     name = models.CharField(max_length=32)
-    model_exception = models.ForeignKey('ModelException', related_name='parsers')
+    model_exception = models.ForeignKey(
+        "ModelException", on_delete=models.CASCADE, related_name="parsers"
+    )
